==> dotclear_2.4.2+dfsg.orig.tar.gz: dotclear-2.4.2+dfsg/themes/ductile/locales/fr/admin.lang.php <==
<?php
# -- BEGIN LICENSE BLOCK ---------------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2011 Olivier Meunier & Association Dotclear
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK -----------------------------------------#
#
#
#        DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['Theme configuration upgraded.'] = 'Configuration du thème mise à jour.';
$GLOBALS['__l10n']['Content'] = 'Contenu';
$GLOBALS['__l10n']['Header'] = 'Entête';
$GLOBALS['__l10n']['Hide blog description:'] = 'Cacher la description du blog :';
$GLOBALS['__l10n']['To configure the top menu go to the <a href="%s">Simple Menu administration page</a>.'] = 'Pour configurer le menu allez à la <a href="%s">page d\'administration de l\'extension Menu Simple</a>.';
$GLOBALS['__l10n']['Stickers'] = 'Étiquettes';
$GLOBALS['__l10n']['Stickers (footer)'] = 'Étiquettes (pied de page)';
$GLOBALS['__l10n']['Entries list types and limits'] = 'Types et limites des listes de billets';
$GLOBALS['__l10n']['Entries lists'] = 'Listes de billets';
$GLOBALS['__l10n']['Context'] = 'Contexte';
$GLOBALS['__l10n']['Entries list type'] = 'Type de liste de billets';
$GLOBALS['__l10n']['Number of entries'] = 'Nombre de billets';
$GLOBALS['__l10n']['Home (first page)'] = 'Page d\'accueil (première page)';
$GLOBALS['__l10n']['Home (other pages)'] = 'Page d\'accueil (pages suivantes)';
$GLOBALS['__l10n']['Entries for a category'] = 'Billets d\'une catégorie';
$GLOBALS['__l10n']['Entries for a tag'] = 'Billets pour un mot-clé';
$GLOBALS['__l10n']['Search result entries'] = 'Billets résultants d\'une recherche';
$GLOBALS['__l10n']['Month archive entries'] = 'Billets d\'une archive mensuelle';
$GLOBALS['__l10n']['Title'] = 'Titre';
$GLOBALS['__l10n']['Short'] = 'Court';
$GLOBALS['__l10n']['Full'] = 'Complet';
$GLOBALS['__l10n']['Presentation'] = 'Présentation';
$GLOBALS['__l10n']['General settings'] = 'Paramètres généraux';
$GLOBALS['__l10n']['Mobile specific settings'] = 'Paramètres spécifiques pour les mobiles';
$GLOBALS['__l10n']['Blog title'] = 'Titre du blog';
$GLOBALS['__l10n']['In bold:'] = 'En gras :';
$GLOBALS['__l10n']['Font size (in em by default):'] = 'Taille de police (en em par défaut) :';
$GLOBALS['__l10n']['Color:'] = 'Couleur :';
$GLOBALS['__l10n']['Post title'] = 'Titre des billets';
$GLOBALS['__l10n']['Titles without link'] = 'Titres sans lien';
$GLOBALS['__l10n']['Inside posts links'] = 'Liens dans les billets';
$GLOBALS['__l10n']['Normal and visited links color:'] = 'Couleur des liens normaux et visités :';
$GLOBALS['__l10n']['Active, hover and focus links color:'] = 'Couleur des liens actifs, survolés et ayant le focus :';
$GLOBALS['__l10n']['Fonts'] = 'Polices de caractère';
$GLOBALS['__l10n']['Main:'] = 'Principale :';
$GLOBALS['__l10n']['Secondary:'] = 'Secondaire :';
$GLOBALS['__l10n']['Ductile primary'] = 'Principale de Ductile';
$GLOBALS['__l10n']['Ductile secondary'] = 'Secondaire de Ductile';
$GLOBALS['__l10n']['Times New Roman'] = 'Times New Roman';
$GLOBALS['__l10n']['Georgia'] = 'Georgia';
$GLOBALS['__l10n']['Garamond'] = 'Garamond';
$GLOBALS['__l10n']['Helvetica/Arial'] = 'Helvetica/Arial';
$GLOBALS['__l10n']['Verdana'] = 'Verdana';
$GLOBALS['__l10n']['Trebuchet MS'] = 'Trebuchet MS';
$GLOBALS['__l10n']['Impact'] = 'Impact';
$GLOBALS['__l10n']['Monospace'] = 'Monospace';
$GLOBALS['__l10n']['ratio %.1f'] = 'ratio %.1f';
?>

==> dotclear_2.5.2+dfsg.orig.tar.gz: dotclear-2.5.2+dfsg/themes/ductile/locales/fr/admin.lang.php <==
<?php
# -- BEGIN LICENSE BLOCK ---------------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK -----------------------------------------#
#
#
#        DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['Theme configuration upgraded.'] = 'Configuration du thème mise à jour.';
$GLOBALS['__l10n']['Content'] = 'Contenu';
$GLOBALS['__l10n']['Header'] = 'Entête';
$GLOBALS['__l10n']['Hide blog description:'] = 'Cacher la description du blog :';
$GLOBALS['__l10n']['Logo URL:'] = 'URL du logo :';
$GLOBALS['__l10n']['To configure the top menu go to the <a href="%s">Simple Menu administration page</a>.'] = 'Pour configurer le menu allez à la <a href="%s">page d\'administration de l\'extension Menu Simple</a>.';
$GLOBALS['__l10n']['Stickers'] = 'Étiquettes';
$GLOBALS['__l10n']['Stickers (footer)'] = 'Étiquettes (pied de page)';
$GLOBALS['__l10n']['Entries list types and limits'] = 'Types et limites des listes de billets';
$GLOBALS['__l10n']['Entries lists'] = 'Listes de billets';
$GLOBALS['__l10n']['Context'] = 'Contexte';
$GLOBALS['__l10n']['Entries list type'] = 'Type de liste de billets';
$GLOBALS['__l10n']['Number of entries'] = 'Nombre de billets';
$GLOBALS['__l10n']['Home (first page)'] = 'Page d\'accueil (première page)';
$GLOBALS['__l10n']['Home (other pages)'] = 'Page d\'accueil (pages suivantes)';
$GLOBALS['__l10n']['Entries for a category'] = 'Billets d\'une catégorie';
$GLOBALS['__l10n']['Entries for a tag'] = 'Billets pour un mot-clé';
$GLOBALS['__l10n']['Search result entries'] = 'Billets résultants d\'une recherche';
$GLOBALS['__l10n']['Month archive entries'] = 'Billets d\'une archive mensuelle';
$GLOBALS['__l10n']['Title'] = 'Titre';
$GLOBALS['__l10n']['Short'] = 'Court';
$GLOBALS['__l10n']['Full'] = 'Complet';
$GLOBALS['__l10n']['Miscellaneous options'] = 'Options diverses';
$GLOBALS['__l10n']['Comment preview is not mandatory:'] = 'Prévisualisation du commentaire optionnelle :';
$GLOBALS['__l10n']['Presentation'] = 'Présentation';
$GLOBALS['__l10n']['General settings'] = 'Paramètres généraux';
$GLOBALS['__l10n']['Mobile specific settings'] = 'Paramètres spécifiques pour les mobiles';
$GLOBALS['__l10n']['Blog title'] = 'Titre du blog';
$GLOBALS['__l10n']['In bold:'] = 'En gras :';
$GLOBALS['__l10n']['Font size (in em by default):'] = 'Taille de police (en em par défaut) :';
$GLOBALS['__l10n']['Color:'] = 'Couleur :';
$GLOBALS['__l10n']['Post title'] = 'Titre des billets';
$GLOBALS['__l10n']['Titles without link'] = 'Titres sans lien';
$GLOBALS['__l10n']['Inside posts links'] = 'Liens dans les billets';
$GLOBALS['__l10n']['Normal and visited links color:'] = 'Couleur des liens normaux et visités :';
$GLOBALS['__l10n']['Active, hover and focus links color:'] = 'Couleur des liens actifs, survolés et ayant le focus :';
$GLOBALS['__l10n']['Fonts'] = 'Polices de caractère';
$GLOBALS['__l10n']['Main:'] = 'Principale :';
$GLOBALS['__l10n']['Secondary:'] = 'Secondaire :';
$GLOBALS['__l10n']['none'] = 'aucune';
$GLOBALS['__l10n']['javascript (Adobe)'] = 'javascript (Adobe)';
$GLOBALS['__l10n']['stylesheet (Google)'] = 'feuille de style (Google)';
$GLOBALS['__l10n']['Set main font to default to use webfont below.'] = 'Mettre la police de caractère principale à Défaut pour utiliser la fonte web ci-dessous.';
$GLOBALS['__l10n']['Set secondary font to default to use webfont below.'] = 'Mettre la police de caractère secondaire à Défaut pour utiliser la fonte web ci-dessous.';
$GLOBALS['__l10n']['Webfont family:'] = 'Famille';
$GLOBALS['__l10n']['Webfont URL:'] = 'URL de la fonte web';
$GLOBALS['__l10n']['Webfont API:'] = 'Type d\'API';
$GLOBALS['__l10n']['Ductile primary'] = 'Principale de Ductile';
$GLOBALS['__l10n']['Ductile secondary'] = 'Secondaire de Ductile';
$GLOBALS['__l10n']['Times New Roman'] = 'Times New Roman';
$GLOBALS['__l10n']['Georgia'] = 'Georgia';
$GLOBALS['__l10n']['Garamond'] = 'Garamond';
$GLOBALS['__l10n']['Helvetica/Arial'] = 'Helvetica/Arial';
$GLOBALS['__l10n']['Verdana'] = 'Verdana';
$GLOBALS['__l10n']['Trebuchet MS'] = 'Trebuchet MS';
$GLOBALS['__l10n']['Impact'] = 'Impact';
$GLOBALS['__l10n']['Monospace'] = 'Monospace';
$GLOBALS['__l10n']['ratio %.1f'] = 'ratio %.1f';
?>
